import db from "@/utils/db";
import { NextRequest, NextResponse } from "next/server";

export async function GET(
	req: NextRequest,
	{ params }: { params: { id: string } }
) {
	const category = await db.category.findUnique({
		where: { id: params.id },
	});
	if (!category) {
		return NextResponse.json({ error: "Category not found" }, { status: 404 });
	} else {
		return NextResponse.json(category, { status: 200 });
	}
}

export async function PUT(
	req: NextRequest,
	{ params }: { params: { id: string } }
) {
	const { name, image } = await req.json();
	const category = await db.category.findUnique({
		where: { id: params.id },
	});
	if (!category) {
		return NextResponse.json({ error: "Category not found" }, { status: 404 });
	} else {
		try {
			const updatedCategory = await db.category.update({
				where: { id: params.id },
				data: {
					name,
					image,
				},
			});
			return NextResponse.json(
				{ message: "category updated successfuly", updatedCategory },
				{ status: 200 }
			);
		} catch (error) {
			return NextResponse.json(
				{ error: "Failed to update category" },
				{ status: 500 }
			);
		}
	}
}

export async function DELETE(
	req: NextRequest,
	{ params }: { params: { id: string } }
) {
	const category = await db.category.findUnique({
		where: { id: params.id },
	});
	if (!category) {
		return NextResponse.json({ error: "category not found" }, { status: 404 });
	} else {
		try {
			await db.category.delete({
				where: { id: params.id },
			});
			return NextResponse.json(
				{ message: "category deleted successfuly", category },
				{ status: 200 }
			);
		} catch (error) {
			return NextResponse.json(
				{ error: "Failed to delete category" },
				{ status: 500 }
			);
		}
	}
}
